@@ -1,4 +1,4 @@
-## ----results='hide'------------------------------------------------------
+## ----results='hide'-----------------------------------------------------------
 set.seed(42)
 
 library("Matrix")
@@ -30,12 +30,12 @@ response_window_clean$Target <- as.factor( ifelse(test = grepl('(Spoon|Bottle)',
                                        yes = 'Inanimate', 
                                        no  = 'Animate') )
 
-## ---- warning=FALSE------------------------------------------------------
+## ---- warning=FALSE-----------------------------------------------------------
 (data_summary <- describe_data(response_window_clean, 
                                describe_column='Animate', group_columns=c('Target','ParticipantName')))
 plot(data_summary)
 
-## ---- warning=FALSE------------------------------------------------------
+## ---- warning=FALSE-----------------------------------------------------------
 # aggregate by subject across the response window
 response_window_agg_by_sub <- make_time_window_data(response_window_clean, 
                                                     aois='Animate',
@@ -51,7 +51,7 @@ describe_data(response_window_agg_by_sub, describe_column = "ArcSin", group_colu
 # simple paired t-test between conditions
 t.test(ArcSin ~ Target, data= response_window_agg_by_sub, paired=TRUE)
 
-## ---- warning=FALSE------------------------------------------------------
+## ---- warning=FALSE-----------------------------------------------------------
 # you should almost always sum-code and center your predictors when performing regression analyses
 response_window_agg_by_sub$AgeC <- response_window_agg_by_sub$Age - mean(response_window_agg_by_sub$Age)
 response_window_agg_by_sub$MCDI_TotalC <- response_window_agg_by_sub$MCDI_Total - mean(response_window_agg_by_sub$MCDI_Total)
@@ -59,7 +59,7 @@ response_window_agg_by_sub$MCDI_TotalC <- response_window_agg_by_sub$MCDI_Total
 model <- lm(ArcSin ~ Target*AgeC*MCDI_TotalC, data=response_window_agg_by_sub)
 summary(model)
 
-## ---- warning=FALSE------------------------------------------------------
+## ---- warning=FALSE-----------------------------------------------------------
 response_window_agg <- make_time_window_data(response_window_clean, 
                                              aois='Animate', 
                                              predictor_columns=c('Target','Age','MCDI_Total'))
@@ -72,41 +72,41 @@ response_window_agg$TargetC <- as.numeric(scale(response_window_agg$TargetC, cen
 model_time_window <- lmer(Elog ~ TargetC + (1 + TargetC | Trial) + (1 | ParticipantName), 
                           data = response_window_agg, REML = FALSE)
 # cleanly show important parts of model (see `summary()` for more)
-(est <- broom::tidy(model_time_window, effects="fixed"))
+(est <- broom.mixed::tidy(model_time_window, effects="fixed"))
 
 # use model comparison to attain p-values
 drop1(model_time_window,~.,test="Chi")
 
-## ---- warning=FALSE------------------------------------------------------
+## ---- warning=FALSE-----------------------------------------------------------
 condition_estimate <- with(est, 
                            c(estimate[term=="(Intercept)"] + estimate[term=="TargetC"] / 2,
                              estimate[term=="(Intercept)"] - estimate[term=="TargetC"] / 2))
 
-## ---- warning=FALSE------------------------------------------------------
+## ---- warning=FALSE-----------------------------------------------------------
 exp(condition_estimate)/(1+exp(condition_estimate))
 
-## ---- warning=FALSE------------------------------------------------------
+## ---- warning=FALSE-----------------------------------------------------------
 plot(model_time_window)
 
-## ---- warning=FALSE------------------------------------------------------
+## ---- warning=FALSE-----------------------------------------------------------
 model_time_window_logit <- lmer(LogitAdjusted ~ TargetC + (1 + TargetC | Trial) + (1 | ParticipantName), 
                                 data = response_window_agg, REML = FALSE)
 plot(model_time_window_logit)
 drop1(model_time_window_logit,~.,test="Chi")
-est_logit <- broom::tidy(model_time_window_logit, effects="fixed")
+est_logit <- broom.mixed::tidy(model_time_window_logit, effects="fixed")
 condition_estimate_logit <- with(est_logit, 
                            c(estimate[term=="(Intercept)"] + estimate[term=="TargetC"] / 2,
                              estimate[term=="(Intercept)"] - estimate[term=="TargetC"] / 2))
 exp(condition_estimate_logit)/(1+exp(condition_estimate_logit))
 
-## ---- warning=FALSE------------------------------------------------------
+## ---- warning=FALSE-----------------------------------------------------------
 response_window_agg$AgeC <- response_window_agg$Age - mean(response_window_agg$Age)
 response_window_agg$MCDI_TotalC <- response_window_agg$MCDI_Total - mean(response_window_agg$MCDI_Total)
 
 model_time_window_add_predictors <- lmer(Elog ~ TargetC*AgeC*MCDI_TotalC + (1 + TargetC | Trial) + (1 | ParticipantName), 
               data = response_window_agg, REML = FALSE)
 # cleanly show important parts of model (see `summary()` for more)
-broom::tidy(model_time_window_add_predictors, effects="fixed")
+broom.mixed::tidy(model_time_window_add_predictors, effects="fixed")
 
 # use model comparison to attain p-values
 drop1(model_time_window_add_predictors,~.,test="Chi")
